==> blesta-5.10.2.zip: blesta/plugins/order/language/de_de/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Wiederherstellungs-E-Mail (optional)';
$lang['Signup.!error.email.blacklist'] = 'Ihre Bestellung kann zur Zeit nicht bearbeitet werden.';
$lang['Signup.index.signup_btn'] = 'Konto erstellen';
$lang['Signup.index.continue_btn'] = 'Weiter zur Kasse';
$lang['Signup.index.login_btn'] = 'Einloggen';
$lang['Signup.index.field_receive_email_marketing'] = 'Ich möchte per E-Mail über neue Produkte, Dienstleistungen und Angebote informiert werden.';
$lang['Signup.index.field_confirmpassword'] = 'Bestätigen Sie Ihr Passwort';
$lang['Signup.index.field_newpassword'] = 'Passwort';
$lang['Signup.index.field_password'] = 'Passwort';
$lang['Signup.index.field_username'] = 'Benutzername';
$lang['Signup.index.field_action_signup'] = 'Ein Konto erstellen';
$lang['Signup.index.field_action_login'] = 'Einloggen';
$lang['Signup.index.field_action_continue'] = 'Weiter als %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Geben Sie einen Benutzernamen an';
$lang['Signup.index.field_username_type_email'] = 'E-Mail als Benutzernamen verwenden';
$lang['Signup.index.field_email'] = 'E-Mail';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_title'] = 'Titel';
$lang['Signup.index.field_country'] = 'Land';
$lang['Signup.index.field_zip'] = 'Postleitzahl/Postleitzahl';
$lang['Signup.index.field_state'] = 'Staat/Provinz';
$lang['Signup.index.field_city'] = 'Stadt';
$lang['Signup.index.field_address2'] = 'Adresse 2';
$lang['Signup.index.field_address1'] = 'Adresse 1';
$lang['Signup.index.field_company'] = 'Unternehmen/Organisation.';
$lang['Signup.index.field_lastname'] = 'Nachname';
$lang['Signup.index.field_firstname'] = 'Vorname';
$lang['Signup.index.field_taxid'] = 'Steuer-ID/VATIN';
$lang['Signup.!notice.email_verification'] = 'Es wurde eine Nachricht zur Verifizierung Ihrer E-Mail-Adresse gesendet. Bitte schließen Sie die Verifizierung so bald wie möglich ab.';
$lang['Signup.!notice.force_email_usernames'] = 'Ihr Benutzername ist derselbe wie Ihre E-Mail-Adresse.';
$lang['Signup.!error.not_client_owner'] = 'Sie müssen als Client-Eigentümer angemeldet sein, um fortfahren zu können.';
$lang['Signup.!error.captcha.invalid'] = 'Das eingegebene Captcha war ungültig. Bitte versuchen Sie es erneut.';

==> blesta-5.11.4.zip: blesta/plugins/order/language/de_de/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Wiederherstellungs-E-Mail (optional)';
$lang['Signup.!error.email.blacklist'] = 'Ihre Bestellung kann zur Zeit nicht bearbeitet werden.';
$lang['Signup.index.signup_btn'] = 'Konto erstellen';
$lang['Signup.index.continue_btn'] = 'Weiter zur Kasse';
$lang['Signup.index.login_btn'] = 'Einloggen';
$lang['Signup.index.field_receive_email_marketing'] = 'Ich möchte per E-Mail über neue Produkte, Dienstleistungen und Angebote informiert werden.';
$lang['Signup.index.field_confirmpassword'] = 'Bestätigen Sie Ihr Passwort';
$lang['Signup.index.field_newpassword'] = 'Passwort';
$lang['Signup.index.field_password'] = 'Passwort';
$lang['Signup.index.field_username'] = 'Benutzername';
$lang['Signup.index.field_action_signup'] = 'Ein Konto erstellen';
$lang['Signup.index.field_action_login'] = 'Einloggen';
$lang['Signup.index.field_action_continue'] = 'Weiter als %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Geben Sie einen Benutzernamen an';
$lang['Signup.index.field_username_type_email'] = 'E-Mail als Benutzernamen verwenden';
$lang['Signup.index.field_email'] = 'E-Mail';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_title'] = 'Titel';
$lang['Signup.index.field_country'] = 'Land';
$lang['Signup.index.field_zip'] = 'Postleitzahl/Postleitzahl';
$lang['Signup.index.field_state'] = 'Staat/Provinz';
$lang['Signup.index.field_city'] = 'Stadt';
$lang['Signup.index.field_address2'] = 'Adresse 2';
$lang['Signup.index.field_address1'] = 'Adresse 1';
$lang['Signup.index.field_company'] = 'Unternehmen/Organisation.';
$lang['Signup.index.field_lastname'] = 'Nachname';
$lang['Signup.index.field_firstname'] = 'Vorname';
$lang['Signup.index.field_taxid'] = 'Steuer-ID/VATIN';
$lang['Signup.!notice.email_verification'] = 'Es wurde eine Nachricht zur Verifizierung Ihrer E-Mail-Adresse gesendet. Bitte schließen Sie die Verifizierung so bald wie möglich ab.';
$lang['Signup.!notice.force_email_usernames'] = 'Ihr Benutzername ist derselbe wie Ihre E-Mail-Adresse.';
$lang['Signup.!error.not_client_owner'] = 'Sie müssen als Client-Eigentümer angemeldet sein, um fortfahren zu können.';
$lang['Signup.!error.captcha.invalid'] = 'Das eingegebene Captcha war ungültig. Bitte versuchen Sie es erneut.';
$lang['Signup.otp.field_submit'] = 'Einloggen';
$lang['Signup.otp.field_otp'] = 'Einmaliges Passwort';
$lang['Signup.otp.login_heading'] = 'Einloggen';
$lang['Signup.otp.description'] = 'Bitte geben Sie Ihr One Time Password ein.';
$lang['Signup.otp.page_title'] = 'Einloggen';
$lang['Signup.index.field_agree_tos'] = 'Ich habe die <a href="%1$s" target="_blank">Allgemeinen Geschäftsbedingungen</a> gelesen und stimme ihnen zu.';
$lang['Signup.!error.invalid_agree_tos'] = 'Sie müssen Ihr Einverständnis mit den Bedingungen und Konditionen bestätigen.';
